==> portal-transparencia-2.036.0.zip: BOOT-INF/classes/db/sql/aise/cargo.sql <==
SELECT CF.ENTIDADE, CF.CARGO, CF.QUADROSALARIAL, CF.GRUPOOCUPACIONAL, CF.NIVEL, 
       GOF.FAIXA, GOF.DESCRICAO AS FAIXADESC, GOF.VALOR, GOF.VALORGRATIFICACAO,
       C.DESCRICAO, CL.DESCRICAO AS TIPO, CF.QUADROSALARIAL, QS.DESCRICAO AS QUADROSALARIALDESC,
       GO.DESCRICAO AS GRUPOOCUPACIONALDESC, GN.DESCRICAO AS NIVELDESC, C.VAGAS AS VAGASTOTAL,
       C.OCUPADAS AS VAGASOCUPADAS
  FROM ${db.aise.schema}.RHCARGOFAIXA CF
 INNER JOIN ${db.aise.schema}.RHCARGO C
    ON CF.ENTIDADE = C.ENTIDADE
   AND CF.CARGO = C.CARGO  
  LEFT OUTER JOIN ${db.aise.schema}.RHCLASSIFICACAOCARGO CL
    ON CL.CLASSIFICACAO = C.CLASSIFICACAO
  LEFT OUTER JOIN ${db.aise.schema}.RHQUADROSALARIAL QS
    ON CF.ENTIDADE = QS.ENTIDADE
   AND CF.QUADROSALARIAL = QS.QUADROSALARIAL
  LEFT OUTER JOIN ${db.aise.schema}.RHGRUPOOCUPACIONAL GO
    ON CF.ENTIDADE = GO.ENTIDADE
   AND CF.QUADROSALARIAL = GO.QUADROSALARIAL
   AND CF.GRUPOOCUPACIONAL = GO.GRUPOOCUPACIONAL
  LEFT OUTER JOIN ${db.aise.schema}.RHGRUPOOCUPACIONALNIVEL GN
    ON CF.ENTIDADE = GN.ENTIDADE
   AND CF.QUADROSALARIAL = GN.QUADROSALARIAL
   AND CF.GRUPOOCUPACIONAL = GN.GRUPOOCUPACIONAL
   AND GN.NIVEL BETWEEN CF.NIVEL AND CF.NIVELFINAL
  LEFT OUTER JOIN ${db.aise.schema}.RHGRUPOOCUPACIONALFAIXA GOF
    ON GN.ENTIDADE = GOF.ENTIDADE
   AND GN.QUADROSALARIAL = GOF.QUADROSALARIAL
   AND GN.GRUPOOCUPACIONAL = GOF.GRUPOOCUPACIONAL
   AND GN.NIVEL = GOF.NIVEL
 WHERE CF.ENTIDADE = :entidade
   AND ${db.aise.schema}.FNC_GETNUMEROFAIXA(GOF.FAIXA, CF.PADRAONIVELINICIAL) >= ${db.aise.schema}.FNC_GETNUMEROFAIXA(CF.FAIXAINICIAL, CF.PADRAONIVELINICIAL)
   AND ${db.aise.schema}.FNC_GETNUMEROFAIXA(GOF.FAIXA, CF.PADRAONIVELINICIAL) <= ${db.aise.schema}.FNC_GETNUMEROFAIXA(CF.FAIXAFINAL, CF.PADRAONIVELINICIAL)
   AND CF.INICIOVALIDADE = (SELECT MAX(X.INICIOVALIDADE) 
                              FROM ${db.aise.schema}.RHCARGOFAIXA X
                             WHERE X.ENTIDADE = CF.ENTIDADE 
                               AND X.CARGO = CF.CARGO 
                               AND EXTRACT(YEAR FROM X.INICIOVALIDADE) <= :exercicio)
   AND GOF.INICIOVALIDADE = (SELECT MAX(GOFX.INICIOVALIDADE)
                               FROM ${db.aise.schema}.RHGRUPOOCUPACIONALFAIXA GOFX
                               JOIN ${db.aise.schema}.RHGRUPOOCUPACIONALCOMPETENCIA GOCX ON GOFX.ENTIDADE = GOCX.ENTIDADE
                                AND GOFX.QUADROSALARIAL = GOCX.QUADROSALARIAL
                                AND GOFX.GRUPOOCUPACIONAL = GOCX.GRUPOOCUPACIONAL
                                AND GOFX.NIVEL = GOCX.NIVEL
                                AND GOFX.INICIOVALIDADE = GOCX.INICIOVALIDADE
                              WHERE GOFX.ENTIDADE = GOF.ENTIDADE
                                AND GOFX.QUADROSALARIAL = GOF.QUADROSALARIAL
                                AND GOFX.GRUPOOCUPACIONAL = GOF.GRUPOOCUPACIONAL
                                AND GOFX.NIVEL = GOF.NIVEL
                                AND GOFX.FAIXA = GOF.FAIXA
                                AND GOCX.SITUACAO = 1
                                AND EXTRACT(YEAR FROM GOFX.INICIOVALIDADE) <= :exercicio)

==> portal-transparencia-3.22.1.zip: BOOT-INF/classes/db/sql/aise/cargo.sql <==
SELECT CF.ENTIDADE, CF.CARGO, CF.QUADROSALARIAL, CF.GRUPOOCUPACIONAL, CF.NIVEL, 
       GOF.FAIXA, GOF.DESCRICAO AS FAIXADESC, GOF.VALOR, GOF.VALORGRATIFICACAO,
       C.DESCRICAO, CL.DESCRICAO AS TIPO, CF.QUADROSALARIAL, QS.DESCRICAO AS QUADROSALARIALDESC,
       GO.DESCRICAO AS GRUPOOCUPACIONALDESC, GN.DESCRICAO AS NIVELDESC, C.VAGAS AS VAGASTOTAL,
       (SELECT COUNT(*) FROM ${db.aise.schema}.RHFUNCIONARIO F
                     WHERE F.CARGO = CF.CARGO and F.SITUACAO != 3 AND F.ENTIDADE = CF.ENTIDADE) AS VAGASOCUPADAS,
       	   EXTINCAO.DESCRICAO AS DESCEXTINCAO,
       	   EXTINCAO.NUMEROATO AS NUMEXTINCAO,
       	   EXTINCAO.ANOATO AS ANOEXTINCAO,
       	   EXTINCAO.INICIOVIGENCIA AS INIVIGENCIAEXTINCAO,
          CASE C.SITUACAO
                   WHEN 'A' THEN 'Ativo'
                   WHEN 'C' THEN 'Cedido'
                   WHEN 'E' THEN 'Extinto'
                   WHEN 'I' THEN 'Inativo'
                   WHEN 'M' THEN 'Em Extinção'
                   WHEN 'T' THEN 'Transformado'
                   ELSE 'Outros'
       	   END AS CARGOSITUACAO
  FROM ${db.aise.schema}.RHCARGOFAIXA CF
 INNER JOIN ${db.aise.schema}.RHCARGO C
    ON CF.ENTIDADE = C.ENTIDADE
   AND CF.CARGO = C.CARGO  
  LEFT OUTER JOIN ${db.aise.schema}.RHCLASSIFICACAOCARGO CL
    ON CL.CLASSIFICACAO = C.CLASSIFICACAO
  LEFT OUTER JOIN ${db.aise.schema}.RHQUADROSALARIAL QS
    ON CF.ENTIDADE = QS.ENTIDADE
   AND CF.QUADROSALARIAL = QS.QUADROSALARIAL
  LEFT OUTER JOIN ${db.aise.schema}.RHGRUPOOCUPACIONAL GO
    ON CF.ENTIDADE = GO.ENTIDADE
   AND CF.QUADROSALARIAL = GO.QUADROSALARIAL
   AND CF.GRUPOOCUPACIONAL = GO.GRUPOOCUPACIONAL
  LEFT OUTER JOIN ${db.aise.schema}.RHGRUPOOCUPACIONALNIVEL GN
    ON CF.ENTIDADE = GN.ENTIDADE
   AND CF.QUADROSALARIAL = GN.QUADROSALARIAL
   AND CF.GRUPOOCUPACIONAL = GN.GRUPOOCUPACIONAL
   AND GN.NIVEL BETWEEN CF.NIVEL AND CF.NIVELFINAL
  LEFT OUTER JOIN ${db.aise.schema}.RHGRUPOOCUPACIONALFAIXA GOF
    ON GN.ENTIDADE = GOF.ENTIDADE
   AND GN.QUADROSALARIAL = GOF.QUADROSALARIAL
   AND GN.GRUPOOCUPACIONAL = GOF.GRUPOOCUPACIONAL
   AND GN.NIVEL = GOF.NIVEL
    LEFT OUTER JOIN ( SELECT MC.CARGO, MC.ENTIDADE, CT.DESCRICAO, CATO.NUMEROATO, CATO.ANOATO, COALESCE(MC.INICIOVIGENCIA, MC.DATAMOVIMENTACAO) AS INICIOVIGENCIA
                           FROM ${db.aise.schema}.RHMOVIMENTACAOCARGO MC
                               JOIN ${db.aise.schema}.CGATO CATO ON CATO.IDATO = MC.IDATO AND CATO.ENTIDADE = MC.ENTIDADE
                               JOIN ${db.aise.schema}.CGTIPOATO CT ON CT.TIPOATO = CATO.TIPOATO
                           WHERE MC.ESPECIE = 8) EXTINCAO ON EXTINCAO.CARGO = C.CARGO AND C.ENTIDADE = EXTINCAO.ENTIDADE
 WHERE CF.ENTIDADE = :entidade
   AND ${db.aise.schema}.FNC_GETNUMEROFAIXA(GOF.FAIXA, CF.PADRAONIVELINICIAL) >= ${db.aise.schema}.FNC_GETNUMEROFAIXA(CF.FAIXAINICIAL, CF.PADRAONIVELINICIAL)
   AND ${db.aise.schema}.FNC_GETNUMEROFAIXA(GOF.FAIXA, CF.PADRAONIVELINICIAL) <= ${db.aise.schema}.FNC_GETNUMEROFAIXA(CF.FAIXAFINAL, CF.PADRAONIVELINICIAL)
   AND CF.INICIOVALIDADE = (SELECT MAX(X.INICIOVALIDADE) 
                              FROM ${db.aise.schema}.RHCARGOFAIXA X
                             WHERE X.ENTIDADE = CF.ENTIDADE 
                               AND X.CARGO = CF.CARGO 
                               AND EXTRACT(YEAR FROM X.INICIOVALIDADE) <= :exercicio)
   AND GOF.INICIOVALIDADE = (SELECT MAX(GOFX.INICIOVALIDADE)
                               FROM ${db.aise.schema}.RHGRUPOOCUPACIONALFAIXA GOFX
                               JOIN ${db.aise.schema}.RHGRUPOOCUPACIONALCOMPETENCIA GOCX ON GOFX.ENTIDADE = GOCX.ENTIDADE
                                AND GOFX.QUADROSALARIAL = GOCX.QUADROSALARIAL
                                AND GOFX.GRUPOOCUPACIONAL = GOCX.GRUPOOCUPACIONAL
                                AND GOFX.NIVEL = GOCX.NIVEL
                                AND GOFX.INICIOVALIDADE = GOCX.INICIOVALIDADE
                              WHERE GOFX.ENTIDADE = GOF.ENTIDADE
                                AND GOFX.QUADROSALARIAL = GOF.QUADROSALARIAL
                                AND GOFX.GRUPOOCUPACIONAL = GOF.GRUPOOCUPACIONAL
                                AND GOFX.NIVEL = GOF.NIVEL
                                AND GOFX.FAIXA = GOF.FAIXA
                                AND GOCX.SITUACAO = 1
                                AND EXTRACT(YEAR FROM GOFX.INICIOVALIDADE) <= :exercicio)
